@@ -8,17 +8,23 @@ pk1 <- read_pubkey("../keys/id_ecdsa521.pub")
 
 test_that("reading protected keys", {
   sk2 <- read_key("../keys/id_ecdsa521.pw", password = "test")
+  sk3 <- read_key("../keys/id_ecdsa521.openssh")
+  sk4 <- read_key("../keys/id_ecdsa521.openssh.pw", password = "test")
   expect_equal(sk1, sk2)
+  expect_equal(sk1, sk3)
+  expect_equal(sk1, sk4)
   expect_error(read_key("../keys/id_ecdsa521.pw", password = NULL), "bad")
 })
 
 test_that("reading public key formats", {
   pk2 <- read_pubkey("../keys/id_ecdsa521.pem")
   pk3 <- read_pubkey("../keys/id_ecdsa521.pub")
-  pk4 <- as.list(sk1)$pubkey
+  pk4 <- read_pubkey("../keys/id_ecdsa521.pub")
+  pk5 <- as.list(sk1)$pubkey
   expect_equal(pk1, pk2)
   expect_equal(pk1, pk3)
   expect_equal(pk1, pk4)
+  expect_equal(pk1, pk5)
 })
 
 test_that("pubkey ssh fingerprint", {
@@ -33,16 +39,20 @@ test_that("signatures", {
   # SHA1 signature
   sig <- readBin("../keys/message.sig.ecdsa521.sha1", raw(), 1000)
   expect_true(signature_verify(msg, sig, sha1, pk1))
+  expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
 
   sig <- signature_create(msg, sha1, sk1)
   expect_true(signature_verify(msg, sig, sha1, pk1))
+  expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
 
   # SHA256 signature
   sig <- readBin("../keys/message.sig.ecdsa521.sha256", raw(), 1000)
   expect_true(signature_verify(msg, sig, sha256, pk1))
+  expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
 
   sig <- signature_create(msg, sha256, sk1)
   expect_true(signature_verify(msg, sig, sha256, pk1))
+  expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
 })
 
 test_that("roundtrip pem format", {
@@ -63,6 +73,7 @@ test_that("signature path interface", {
   sig <- signature_create("../keys/message", sha256, "../keys/id_ecdsa521")
   writeBin(sig, tmp <- tempfile())
   expect_true(signature_verify("../keys/message", tmp, sha256, "../keys/id_ecdsa521.pub"))
+  expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
 })
 
 test_that("ec_keygen works", {
